@@ -2,19 +2,49 @@
 #'
 #' @param object data.frame
 #' @param uis_breaks A character vector with the names of the UIS breaks if the \code{uis} argument was used in [isatpanel].
+#' @param isat_object The object of class \code{isat} produced by [isatpanel].
 #'
 #' @return A list of data.frames
 #'
-identify_indicator_timings <- function(object, uis_breaks = NULL){
+identify_indicator_timings <- function(object, uis_breaks = NULL, isat_object = NULL){
   varying_vars <- names(object)[!names(object)%in% c("id","time","y","fitted")]
 
   object_l <- reshape(object,
-                  varying = varying_vars,
-                  idvar = c("id","time"),
-                  v.names = "value",
-                  timevar = "name",
-                  times = varying_vars,
-                  direction = "long")
+                      varying = varying_vars,
+                      idvar = c("id","time"),
+                      v.names = "value",
+                      timevar = "name",
+                      times = varying_vars,
+                      direction = "long")
+
+  # indicators_identified <- gets::isatdates(isat_object)
+  #
+  # if(!is.null(indicators_identified$iis)){
+  #   iis <- indicators_identified$iis
+  # } else {
+  #   iis <- NULL
+  # }
+  #
+  #
+  # if(!is.null(indicators_identified$tis)){
+  #   tis <- indicators_identified$tis
+  # } else {
+  #   tis <- NULL
+  # }
+  #
+  # # sis
+  # if(!is.null(indicators_identified$sis)){
+  #   sis <- indicators_identified$sis
+  # } else {
+  #   sis <- NULL
+  # }
+  #
+  # # uis
+  # if(!is.null(indicators_identified$uis)){
+  #   uis <- indicators_identified$uis
+  # } else {
+  #   uis <- NULL
+  # }
 
   # Impulses and Steps
   impulses <- object_l[grepl("iis",object_l$name) & object_l$value == 1,]
@@ -48,7 +78,12 @@ identify_indicator_timings <- function(object, uis_breaks = NULL){
     fesis_l$id <- unlist(lapply(split_list, `[[`, 1))
     fesis_l$id <- gsub("fesis","",fesis_l$id)
     fesis_l$time <- unlist(lapply(split_list, `[[`, 2))
-    fesis_l$time <- as.numeric(fesis_l$time)
+
+    if(all(is.na(suppressWarnings(as.numeric(fesis_l$time))))){
+      fesis_l$time <- as.Date(fesis_l$time)
+    } else {
+      fesis_l$time <- as.numeric(fesis_l$time)
+    }
 
     fesis_l <- fesis_l[c("id","time","name")]
 
@@ -102,7 +137,6 @@ identify_indicator_timings <- function(object, uis_breaks = NULL){
   } else {cfesis <- NULL}
 
   # CSIS
-
   if(any(grepl("csis",names(object)))){
 
     csis_wide <- object[,grepl("csis", names(object)), drop = FALSE]
@@ -118,7 +152,11 @@ identify_indicator_timings <- function(object, uis_breaks = NULL){
     csis_l$name <- unlist(lapply(split_list, `[[`, 1))
     csis_l$time <- unlist(lapply(split_list, `[[`, 2))
     csis_l$time <- gsub("csis","",csis_l$time)
-    csis_l$time <- as.numeric(csis_l$time)
+    if(all(is.na(suppressWarnings(as.numeric(csis_l$time))))){
+      csis_l$time <- as.Date(csis_l$time)
+    } else {
+      csis_l$time <- as.numeric(csis_l$time)
+    }
 
     csis_l <- csis_l[c("time","name")]
 
