@@ -5,6 +5,7 @@
 #' @param facet.scales To be passed to ggplot2::facet_wrap. Default is "free" (i.e. a separate y axis for each panel group/id). Alternatives are: "fixed", "fixed_y", and "fixed_x".
 #' @param title Plot title. Must be a character vector.
 #' @param zero_line Plot a horizontal line at y = 0. Default is FALSE.
+#' @param regex_exclude_indicators A regex character vector to exclude the inclusion of certain indicators in the plot. Default = NULL. Use with care, experimental.
 #'
 #' @return A ggplot2 plot that plots an 'isatpanel' object and shows the counterfactuals for each break.
 #' @export
@@ -41,11 +42,16 @@
 #' plot_counterfactual(result)
 #'}
 
-plot_counterfactual <- function(x, plus_t = 5, facet.scales = "free", title = NULL, zero_line = FALSE){
+plot_counterfactual <- function(x, plus_t = 5, facet.scales = "free", title = NULL, zero_line = FALSE, regex_exclude_indicators = NULL){
 
   df <- x$estimateddata
   indicators <- x$isatpanel.result$aux$mX
   indicators <- indicators[,!colnames(indicators) %in% names(df)]
+
+  if(!is.null(regex_exclude_indicators)){
+    indicators <- indicators[,!grepl(regex_exclude_indicators,colnames(indicators)),drop = FALSE]
+  }
+
   df <- cbind(df,indicators)
 
   df_ident_fesis <- identify_indicator_timings(df)$fesis
@@ -112,11 +118,11 @@ plot_counterfactual <- function(x, plus_t = 5, facet.scales = "free", title = NU
   if(zero_line){g = g + geom_hline(aes(yintercept = 0))}
 
   g +
-    geom_line(aes(y = .data$y, color = "black"), size = 0.7) +
+    geom_line(aes(y = .data$y, color = "black"), linewidth = 0.7) +
 
     geom_rect(data = effects, aes(xmin = .data$start_rect, xmax = .data$end_rect, ymin = -Inf, ymax = Inf, group = .data$name),fill = "grey",alpha = 0.1, na.rm = TRUE) +
 
-    geom_line(aes(color = "blue"),linetype = 1, size = 0.5) +
+    geom_line(aes(color = "blue"),linetype = 1, linewidth = 0.5) +
 
     # fesis
     geom_vline(data = df_ident_fesis, aes(xintercept = .data$time,color="red")) +
